package com.datacloudsec.utils;

import com.cloudbees.syslog.Facility;
import com.cloudbees.syslog.MessageFormat;
import com.cloudbees.syslog.Severity;
import com.cloudbees.syslog.sender.TcpSyslogMessageSender;
import com.cloudbees.syslog.sender.UdpSyslogMessageSender;
import com.datacloudsec.scan.service.IConfig;
import com.datacloudsec.scan.service.impl.ConfigService;
import com.datacloudsec.utils.InstanceUtil;
import com.datacloudsec.utils.ObjectUtil;
import common.Logger;
import org.apache.commons.lang.StringUtils;

public class SyslogUtil {

   private static final Logger LOG = Logger.getLogger(SyslogUtil.class);
   private static IConfig config = (IConfig)InstanceUtil.newServiceInstance(ConfigService.class);


   public static void send(String msg) throws Exception {
      if("udp".equalsIgnoreCase(ObjectUtil.getString(config.getValueByName("syslog_protocol"), (String)null))) {
         udpSend(msg);
      } else {
         tcpSend(msg);
      }

   }

   public static void send(String ip, Integer port, String protocol, String msg) {
      if("udp".equalsIgnoreCase(protocol)) {
         udpSend(ip, port, msg);
      } else {
         tcpSend(ip, port, msg);
      }

   }

   private static void udpSend(String msg) {
      try {
         String e = ObjectUtil.getString(config.getValueByName("syslog_ip"), (String)null);
         if(StringUtils.isNotBlank(e) && StringUtils.isNotBlank(msg)) {
            UdpSyslogMessageSender messageSender = new UdpSyslogMessageSender();
            messageSender.setDefaultMessageHostname(ObjectUtil.getString(config.getValueByName("syslog_hostname"), "scans_host"));
            messageSender.setDefaultAppName(ObjectUtil.getString(config.getValueByName("syslog_appname"), "scans"));
            messageSender.setDefaultFacility(Facility.USER);
            messageSender.setDefaultSeverity(Severity.INFORMATIONAL);
            messageSender.setSyslogServerHostname(e);
            messageSender.setSyslogServerPort(ObjectUtil.getInt(config.getValueByName("syslog_port"), 514));
            messageSender.setMessageFormat("5424".equalsIgnoreCase(config.getValueByName("syslog_format"))?MessageFormat.RFC_5424:MessageFormat.RFC_3164);
            messageSender.sendMessage(msg);
         }
      } catch (Exception var3) {
         LOG.error("", var3);
      }

   }

   private static void udpSend(String ip, Integer port, String msg) {
      try {
         if(StringUtils.isNotBlank(ip) && StringUtils.isNotBlank(msg)) {
            UdpSyslogMessageSender e = new UdpSyslogMessageSender();
            e.setDefaultMessageHostname("scans_host");
            e.setDefaultAppName("scans");
            e.setDefaultFacility(Facility.USER);
            e.setDefaultSeverity(Severity.INFORMATIONAL);
            e.setSyslogServerHostname(ip);
            e.setSyslogServerPort(ObjectUtil.getInt(port, 514));
            e.sendMessage(msg);
         }
      } catch (Exception var4) {
         LOG.error("", var4);
      }

   }

   private static void tcpSend(String msg) {
      try {
         String e = ObjectUtil.getString(config.getValueByName("syslog_ip"), (String)null);
         if(StringUtils.isNotBlank(e) && StringUtils.isNotBlank(msg)) {
            TcpSyslogMessageSender messageSender = new TcpSyslogMessageSender();
            messageSender.setDefaultMessageHostname(ObjectUtil.getString(config.getValueByName("syslog_hostname"), "scans_host"));
            messageSender.setDefaultAppName(ObjectUtil.getString(config.getValueByName("syslog_appname"), "scans"));
            messageSender.setDefaultFacility(Facility.USER);
            messageSender.setDefaultSeverity(Severity.INFORMATIONAL);
            messageSender.setSyslogServerHostname(e);
            messageSender.setSyslogServerPort(ObjectUtil.getInt(config.getValueByName("syslog_port"), 514));
            messageSender.setMessageFormat("5424".equalsIgnoreCase(config.getValueByName("syslog_format"))?MessageFormat.RFC_5424:MessageFormat.RFC_3164);
            messageSender.setSsl(false);
            messageSender.sendMessage(msg);
         }
      } catch (Exception var3) {
         LOG.error("", var3);
      }

   }

   private static void tcpSend(String ip, Integer port, String msg) {
      try {
         if(StringUtils.isNotBlank(ip) && StringUtils.isNotBlank(msg)) {
            TcpSyslogMessageSender e = new TcpSyslogMessageSender();
            e.setDefaultMessageHostname("scans_host");
            e.setDefaultAppName("scans");
            e.setDefaultFacility(Facility.USER);
            e.setDefaultSeverity(Severity.INFORMATIONAL);
            e.setSyslogServerHostname(ip);
            e.setSyslogServerPort(ObjectUtil.getInt(port, 514));
            e.setSsl(false);
            e.sendMessage(msg);
         }
      } catch (Exception var4) {
         LOG.error("", var4);
      }

   }

   public static void main(String[] args) throws Exception {
      send("This is a test message");
   }
}
